package com.yonge.cooleshow.biz.dal.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dayaedu.cbs.openfeign.client.CoursewareFeignService;
import com.dayaedu.cbs.openfeign.wrapper.courseware.CbsLessonCoursewareWrapper;
import com.yonge.cooleshow.biz.dal.dao.LessonCoursewareDao;
import com.yonge.cooleshow.biz.dal.entity.LessonCourseware;
import com.yonge.cooleshow.biz.dal.entity.Subject;
import com.yonge.cooleshow.biz.dal.service.LessonCoursewareService;
import com.yonge.cooleshow.biz.dal.service.SubjectService;
import com.yonge.cooleshow.biz.dal.wrapper.LessonCoursewareWrapper;
import com.yonge.toolset.utils.collection.MapUtil;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;


@Service
public class LessonCoursewareServiceImpl extends ServiceImpl<LessonCoursewareDao, LessonCourseware> implements LessonCoursewareService {
    private final static Logger log = LoggerFactory.getLogger(LessonCoursewareServiceImpl.class);

    @Resource
    private CoursewareFeignService coursewareFeignService;
    @Resource
    private SubjectService subjectService;

    public LessonCoursewareDao getBaseMapper() {
        return this.baseMapper;
    }

    @Override
    public IPage<LessonCoursewareWrapper.LessonCoursewareDto> selectPage(IPage<LessonCoursewareWrapper.LessonCoursewareDto> page, LessonCoursewareWrapper.LessonCoursewareQuery query) {
        List<LessonCoursewareWrapper.LessonCoursewareDto> dtos = baseMapper.selectPage(page, query);
        if(CollectionUtils.isNotEmpty(dtos)){
            List<Long> lessonCoursewareIds = dtos.stream().map(LessonCoursewareWrapper.LessonCoursewareDto::getLessonCoursewareId).collect(Collectors.toList());
            CbsLessonCoursewareWrapper.LambdaQuery lambdaQuery = new CbsLessonCoursewareWrapper.LambdaQuery();
            lambdaQuery.setIds(lessonCoursewareIds);
            List<CbsLessonCoursewareWrapper.Entity> entityList = coursewareFeignService.lessonCoursewareLambdaQuery(lambdaQuery).feignData();
            if(CollectionUtils.isNotEmpty(entityList)){
                Map<Long, CbsLessonCoursewareWrapper.Entity> entityMap = entityList.stream().collect(Collectors.groupingBy(CbsLessonCoursewareWrapper.Entity::getId,
                        Collectors.collectingAndThen(Collectors.toList(), e -> e.get(0))));
                for (LessonCoursewareWrapper.LessonCoursewareDto e : dtos) {
                    CbsLessonCoursewareWrapper.Entity entity = entityMap.get(e.getLessonCoursewareId());
                    if (Objects.isNull(entity)) {
                        continue;
                    }
                    e.setName(entity.getName());
                    e.setCover(entity.getCoverImg());
                    e.setCourseNum(entity.getCourseNum());
                }
            }
            List<Integer> collect = dtos.stream().map(e -> e.getSubjectId()).collect(Collectors.toList());
            if(CollectionUtils.isNotEmpty(collect)){
                List<String> subjectIds = collect.stream().map(e -> String.valueOf(e)).collect(Collectors.toList());
                Map<Integer, Subject> subjectMap = subjectService.getMapByIds(subjectIds);
                for (LessonCoursewareWrapper.LessonCoursewareDto e : dtos) {
                    Subject subject = subjectMap.get(e.getSubjectId());
                    if (Objects.isNull(subject)) {
                        continue;
                    }
                    e.setSubjectName(subject.getName());
                }
            }
        }
        return page.setRecords(dtos);
    }
}