package com.yonge.cooleshow.biz.dal.wrapper;

import com.alibaba.fastjson.JSON;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.yonge.cooleshow.biz.dal.enums.ClientEnum;
import com.yonge.cooleshow.biz.dal.enums.MessageSendMode;
import com.yonge.cooleshow.biz.dal.enums.MessageTypeEnum;
import com.yonge.cooleshow.biz.dal.enums.SendStatusEnum;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;

/**
 * 消息表
 * 2023-10-25 16:05:36
 */
@ApiModel(value = "SysMessageWrapper对象", description = "消息表查询对象")
public class SysMessageWrapper {

    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @ApiModel(" SysMessageQuery-消息表")
    public static class SysMessageQuery implements QueryInfo {
        @ApiModelProperty("当前页")
        private Integer page;

        @ApiModelProperty("分页行数")
        private Integer rows;

        @ApiModelProperty(value = "发送人编号")
        private Long userId;

        @ApiModelProperty("客户端STUDENT,TEACHER,BACKEND,SCHOOL")
        private ClientEnum clientId;

        private ClientEnum clientType;

        @ApiModelProperty(value = "状态，0,待发送;1,发送中;2,发送完成 ")
        private SendStatusEnum status;

        @ApiModelProperty(value = "接收人编号")
        private String receiver;

        @ApiModelProperty(value = "消息类型；1，表示短信；2，表示邮件; 3,app推送消息",required = false)
        private MessageSendMode type;

        @ApiModelProperty("消息组 ")
        private String group;

        @ApiModelProperty("0:未读，1：已读")
        private Boolean readStatus;

        @ApiModelProperty("消息类型EMessageType,多个用逗号隔开，验证码登录：SMS_VERIFY_CODE_LOGIN，密码修改：SMS_VERIFY_CODE_UPDATE_PSW")
        private String messageType;

        @ApiModelProperty("发送开始时间")
        private Date startTime;

        @ApiModelProperty("发送结束时间")
        private Date endTime;

        // 发送时间
        private Date sendTime;

        private Long messageConfigId;

        public String jsonString() {
            return JSON.toJSONString(this);
        }

    }

    @Data
    @ApiModel(" SysMessage-消息表")
    public static class SysMessage {

        @ApiModelProperty("主键")
        private Long id;

        @ApiModelProperty("用户编号")
        private Long userId;

        @ApiModelProperty("消息配置id")
        private Long messageConfigId;

        @ApiModelProperty("消息类型；1，表示短信；2，表示邮件; 3,app推送消息")
        private String type;

        @ApiModelProperty("标题")
        private String title;

        @ApiModelProperty("消息内容")
        private String content;

        @ApiModelProperty("状态，-1,发送失败;0,待发送;1,发送中;2,发送完成")
        private SendStatusEnum status;

        @ApiModelProperty("接收人(多个人用逗号分隔)")
        private String receiver;

        @ApiModelProperty("发送时间")
        private Date sendTime;

        @ApiModelProperty("错误信息")
        private String errorMsg;

        @ApiModelProperty("创建时间")
        private Date createOn;

        @ApiModelProperty("修改时间")
        private Date modifyOn;

        @ApiModelProperty("备注")
        private String memo;

        @ApiModelProperty("是否已读")
        private Boolean readStatus;

        @ApiModelProperty("消息组")
        private String group;

        @ApiModelProperty("客户端STUDENT,TEACHER,SYSTEM")
        private String clientId;

        @ApiModelProperty("跳转信息")
        private String url;

        @ApiModelProperty("TEACHER_AUTH:达人认证,MUSICIAN_AUTH:音乐人认证,PRACTICE:陪练课,LIVE:直播课,VIDEO:视频课,MUSIC_SHEET:乐谱," +
                "COURSE:课程,INCOME:收入,HOMEWORK:作业,EVALUATE:评价,GROUP_CHAT:群聊,VIP:会员,NOTICE:公告")
        private String subType;


        @ApiModelProperty("验证码")
        private String verityCode;

        @ApiModelProperty("消息类型")
        private String messageType;

        public String jsonString() {
            return JSON.toJSONString(this);
        }

        public static SysMessage from(String json) {
            return JSON.parseObject(json, SysMessage.class);
        }
    }

    @Data
    @ApiModel("未读消息统计")
    public static class MessageUnreadStat implements Serializable {

        @ApiModelProperty("消息分组")
        private String group;

        @ApiModelProperty("未读消息数")
        private Integer number;
    }

    /**
     * 消息设置一键读取条件
     */
    @Data
    public static class MessageRead {

        private MessageTypeEnum messageType;
    }

}